@@ -7,3 +7,6 @@ API_SET_TEMPERATURE_URL = API_BASE_URL + "/api/thermostat"
 API_APPLICATION_ID = 7
 HTTP_UNAUTHORIZED: int = 401
 HTTP_OK: int = 200
+HVAC_MODE_AWAY = 1
+HVAC_MODE_SCHEDULE = 2
+HVAC_MODE_MANUAL = 3
